@@ -2,7 +2,7 @@ package Benchmark::Confirm;
 use strict;
 use warnings;
 
-our $VERSION = '0.22';
+our $VERSION = '1.00';
 
 =head1 NAME
 
@@ -89,6 +89,51 @@ You can use this function when you write some benchmarks in one script. Or you s
 This function resets stacks of returned value.
 
 
+=head1 IMPORT OPTIONS
+
+=head2 TAP
+
+If you want to get valid TAP result, you should add import option C<TAP>.
+
+    perl -MBenchmark::Confirm=TAP some_benchmark.pl
+
+Then you get results as valid TAP like below.
+
+    # Benchmark: timing 1 iterations of Name1, Name2, Name3...
+    #      Name1:  0 wallclock secs ( 0.00 usr +  0.00 sys =  0.00 CPU)
+    #             (warning: too few iterations for a reliable count)
+    #      Name2:  0 wallclock secs ( 0.00 usr +  0.00 sys =  0.00 CPU)
+    #             (warning: too few iterations for a reliable count)
+    #      Name3:  0 wallclock secs ( 0.00 usr +  0.00 sys =  0.00 CPU)
+    #             (warning: too few iterations for a reliable count)
+    #                     Rate Name3 Name1 Name2
+    # Name3 10000/s    --    0%    0%
+    # Name1 10000/s    0%    --    0%
+    # Name2 10000/s    0%    0%    --
+    ok 1
+    ok 2
+    ok 3
+    1..3
+
+=head2 no_plan
+
+If you want to add more tests with benchmarks, you should use import option C<no_plan>.
+
+    use Benchmark::Confirm qw/no_plan timethese cmpthese/;
+
+    my $result = timethese( 1 => +{
+        Name1 => sub { "something" },
+        Name2 => sub { "something" },
+        Name3 => sub { "something" },
+    });
+
+    cmpthese $result;
+
+    ok 1, 'additionaly';
+
+Don't worry, C<Test::More::done_testing> invokes in C<END> block of Benchmark::Confirm. So you don't need write that.
+
+
 =head1 CAVEATS
 
 If benchmark code returns CODE reference, then C<Benchmark::Confirm> treats it as string value: 'CODE'. This may change in future releases.
@@ -118,23 +163,52 @@ modify it under the same terms as Perl itself. See L<perlartistic>.
 =cut
 
 use Benchmark;
+use Test::More;
+
+my $capture;
 
 sub import {
-    Benchmark->export_to_level(1, @_);
+    my $class = shift;
+
+    my $caller = caller;
+
+    my @imports = ($class);
+    for my $func (@_) {
+        next unless $func;
+        if ($func eq 'TAP') {
+            require IO::Capture::Stdout;
+            $capture = IO::Capture::Stdout->new;
+            $capture->start;
+        }
+        elsif ($func eq 'no_plan') {
+            no strict 'refs'; ## no critic
+            for my $f ( @Test::More::EXPORT ) {
+                *{"${caller}::$f"} = \&{"Test::More::$f"};
+            }
+        }
+        else {
+            push @imports, $func;
+        }
+    }
+    Benchmark->export_to_level(1, @imports);
 }
 
 our @CONFIRMS;
 
 END {
+    if (ref $capture eq 'IO::Capture::Stdout') {
+        $capture->stop;
+        while ( my $line = $capture->read ) {
+            print "# ${line}"; # valid TAP
+        }
+    }
     if (@CONFIRMS > 1) {
-        atonce() ;
+        atonce();
         Test::More::done_testing();
     }
 }
 
 sub atonce {
-    require Test::More;
-
     my $expect = _normalize(shift @CONFIRMS);
     Test::More::ok(1);
 
